@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1555.2.1 2023/11/18 11:01:31 sdk Exp $
+# $OpenBSD: Quirks.pm,v 1.1436 2022/09/22 09:59:59 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -566,6 +566,7 @@ my $stem_extensions = {
 	'py-waitress' => 'py3-waitress',
 	'py-webencodings' => 'py3-webencodings',
 	'py-xmltodict' => 'py3-xmltodict',
+	'py-zc-lockfilezc.lockfile' => 'py3-zc-lockfilezc.lockfile',
 	'py-jaraco-functools' => 'py3-jaraco-functools',
 	'py-logilab-common' => 'py3-logilab-common',
 	'py-memcached' => 'py3-memcached',
@@ -746,46 +747,6 @@ my $stem_extensions = {
 	'py-dbus' => 'py3-dbus',
 	'dspy' => 'd-spy',
 	'i3-mousedrag' => 'i3',
-# 7.3
-	'spidermonkey91' => 'spidermonkey102',
-	'dleyna-core' => 'dleyna',
-	'gnome-todo' => 'endeavour',
-	'go-ipfs' => 'kubo',
-	'py-zc-lockfilezc.lockfile' => 'py3-zc-lockfile',
-	'py3-zc-lockfilezc.lockfile' => 'py3-zc-lockfile',
-	'py-elfesteem' => 'py3-miasm', # merged
-	'py-miasm' => 'py3-miasm',
-	'py-cssselect' => 'py3-cssselect',
-	'py-cparser' => 'py3-cparser',
-	'py-authres' => 'py3-authres',
-	'py-policyd-spf' => 'py3-policyd-spf',
-	'py-spf' => 'py3-spf',
-	'py-nose' => 'py3-nose',
-	'py-xdg' => 'py3-xdg',
-	'i3-gaps' => 'i3',
-	'rebar' => 'rebar3',
-	'gortr' => 'stayrtr',
-	'py-wxPython' => 'py3-wxPython',
-	'py-modulegraph' => 'py3-modulegraph',
-	'py-psutil' => 'py3-psutil',
-	'py-lxml' => 'py3-lxml',
-	'py-pyglet' => 'py3-pyglet',
-	'py-suds' => 'py3-suds',
-	'py-serial' => 'py3-serial',
-	'py3-wxPython-webkit' => 'py3-wxPython-webview',
-	'wxWidgets-webkit' => 'wxWidgets-webview',
-	'ring' => 'rust-ring',
-# 7.4
-	'aarch64-none-elf-gcc-linaro' => 'aarch64-none-elf-gcc',
-	'arm-none-eabi-gcc-linaro' => 'arm-none-eabi-gcc',
-	'py3-sabyenc' => 'py3-sabctools',
-	'py-libdnet' => 'py3-libdnet',
-	'scons-py2' => 'scons',
-	'qxlsx' => 'qt5-qxlsx',
-	'py-altgraph' => 'py3-altgraph',
-	'pymodbus' => 'py3-pymodbus',
-	'py-yaml' => 'py3-yaml',
-	'kalendar' => 'merkuro',
 };
 
 my $obsolete_reason = {};
@@ -812,6 +773,7 @@ setup_obsolete_reason(
 	6 => 'empathy',
 	3 => 'telepathy-salut',
 	3 => 'telepthy-haze',
+	3 => 'telepathy-idle',
 	3 => 'telepathy-gabble',
 	3 => 'telepathy-qt',
 	3 => 'telepathy-farstream',
@@ -1366,7 +1328,7 @@ setup_obsolete_reason(
 	0 => 'lazarus',
 	13 => 'exaile',
 	3 => 'instead-launcher',
-	3 => qr{^(ruby(19|2[0-7])-|^j?ruby-[^0-9])},
+	3 => qr{^(ruby(19|2[0-6])-|ruby-[^0-9])},
 # 6.9
 	3 => 'py-notify',
 	3 => 'glimpse',
@@ -1397,7 +1359,9 @@ setup_obsolete_reason(
 	5 => 'gnome-getting-started-docs',
 	3 => 'py-poppler',
 	3 => 'pdfshuffler',
+	27 => 'colord',
 	27 => 'colord-gtk',
+	5 => 'gnome-color-manager',
 	3 => 'zeya',
 	3 => 'py-trollius',
 	3 => qr{^kde-i18n-},
@@ -1725,7 +1689,9 @@ setup_obsolete_reason(
 	31 => 'py-scandir',
 	3 => 'd-feet',
 # 7.2
+	6 => 'tepl',
 	3 => 'gnome-documents',
+	6 => 'amtk',
 	3 => 'lumail',
 	3 => 'kalarmcal',
 	5 => 'gnats',
@@ -1757,103 +1723,6 @@ setup_obsolete_reason(
 	5 => 'usrsctp',
 	0 => 'shapezio',
 	3 => 'boar',
-# 7.3
-	3 => 'evolution-rss',
-	3 => 'libgfbgraph',
-	3 => 'gnome-online-miners',
-	3 => 'libzapojit',
-	3 => 'librest',
-	3 => 'seahorse-sharing',
-	48 => 'electron',
-	3 => 'xalan-c',
-	5 => 'xalan-j',
-	5 => 'opencdk',
-	5 => 'klaxon',
-	49 => 'sentinel',
-	50 => 'sslScanner',
-	5 => 'softhsm',
-	1 => 'chntpw',
-	5 => 'nbaudit',
-	1 => 'despoof',
-	51 => 'zebedee',
-	3 => 'slurpie',
-	1 => 'samdump2',
-	1 => 'smbsniff',
-	0 => 'fragroute',
-	52 => 'ikeman',
-	3 => 'libperseus',
-	0 => 'hatchet',
-	51 => 'ctunnel',
-	3 => 'py-libpcap',
-	3 => 'supybot',
-	3 => 'dissy',
-	1 => 'stm32loader',
-	3 => 'tmda',
-	3 => 'spambayes',
-	31 => 'nmap-zenmap',
-	0 => 'uucpd',
-	6 => 'py-sqlite2',
-	31 => 'py-ipaddr',
-	3 => 'hlfl',
-	6 => 'caribou',
-	5 => 'riak',
-	15 => 'rmilter',
-	3 => 'gotweb',
-	6 => 'go-net',
-	6 => 'go-goptlib',
-	0 => 'xco',
-	6 => 'go-sys',
-	6 => 'go-crypto',
-	6 => 'go-ed25519',
-	6 => 'go-siphash',
-	6 => 'go-text',
-	6 => 'cryptcat',
-	6 => 'pilot-link',
-	6 => 'jpilot',
-	3 => 'midori',
-	3 => 'pykaraoke',
-	3 => 'sk1',
-	0 => 'pgadmin3',
-	3 => 'rapidsvn',
-	0 => 'chbg',
-	3 => 'wammu',
-	3 => 'winwrangler',
-	3 => 'gtkhotkey',
-	3 => 'libwnck',
-	6 => 'ap-utils',
-	6 => 'kibana',
-	6 => 'elasticsearch',
-	3 => 'ogmrip',
-	3 => 'shrip',
-# 7.4
-	53 => 'compton',
-	54 => 'depotdownloader',
-	55 => 'residualvm',
-	5 => 'p5-Test-Group',
-	9 => 'thedarkmod',
-	3 => 'qtav',
-	3 => 'ruby31-mysql',
-	3 => 'ruby32-mysql',
-	3 => 'libquicktime',
-	3 => 'gnome-twitch',
-	5 => 'sfio',
-	3 => 'parrot',
-	3 => 'kfloppy',
-	3 => 'py3-hypatia',
-	1 => 'reprepro',
-	5 => 'ocaml-pcre',
-	1 => 'breeze-grub',
-	3 => 'mldonkey',
-	3 => 'monotone',
-	3 => 'botan',
-	3 => 'bg5ps',
-	9 => 'haxe',
-	1 => 'libxcvt',
-	1 => 'ocaml-camlp4',
-	1 => 'ocaml-camlp5',
-	3 => 'freetype',
-	3 => 'freetype-doc',
-	6 => 'ipcheck',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
@@ -1870,8 +1739,6 @@ my $obsolete_suggestion = {
 	'keepassx' => 'keepassxc',
 	'lives' => [qw(kdenlive shotcut)],
 	'pdfshuffler' => 'pdfarranger',
-	'gotweb' => 'gotwebd',
-	'compton' => 'picom',
 };
 
 # reasons for obsolete packages
@@ -1891,7 +1758,6 @@ my $obsolete_message = {
 	12 => "replace with IMAPSieve, see https://wiki.dovecot.org/HowTo/AntispamWithSieve",
 	13 => "has a dependency on obsolete software",
 	14 => "no longer maintained upstream and has security issues, consider remmina or tigervnc's vncviewer as an alternative",
-	15 => "use rspamd's internal milter support instead",
 	17 => "old GeoIP databases end-of-life, see alternative using geoip2/libmaxminddb",
 	20 => "merged into IETF Opus codec, obsolete, audio/mumble uses bundled version now",
 	21 => "upstream recommends to use composer to build a drupal site",
@@ -1917,14 +1783,6 @@ my $obsolete_message = {
 	45 => "crashes in many different ways at runtime",
 	46 => "moved to binary bootstraps",
 	47 => "DNS network daemon running as root and not using random source ports. use DNS64 support in unbound or isc-bind",
-	48 => "horrible ecosystem",
-	49 => "has no license, unmaintained since too long, crashes at runtime",
-	50 => "abandoned ten years ago, broken by default due to missing runtime dependencies, use security/sslscan",
-	51 => "dead upstream, consider using socat or SSH",
-	52 => "unmaintained since import, already on LibreSSL life support for too long",
-	53 => "upstream is dead, consider migrating to picom",
-	54 => "dependencies for recent versions can't be met (dotnet), consider switching to steamctl",
-	55 => "residualvm is dead upstream and has been merged into scummvm",
 };
 
 # ->is_base_system($handle, $state):
@@ -2073,7 +1931,7 @@ my $cve = {
 	'lang/ruby/2.5,-main' => 'ruby->2.5,<2.5.5',
 	'lang/ruby/2.6,-main' => 'ruby->2.6,<2.6.2',
 	'mail/dovecot,-server' => 'dovecot-<2.3.10.1',
-	'mail/exim,-main' => 'exim-<4.97', # ...at least
+	'mail/exim' => 'exim-<4.83',
 	'mail/isync' => 'isync-<1.4.4',
 	'mail/mailman' => 'mailman-<2.1.30',
 	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.4',
@@ -2120,7 +1978,6 @@ my $cve = {
 	'security/sudo' => 'sudo-<1.8.31',
 	'shells/bash' => 'bash-<4.3.27',
 	'sysutils/ansible,-main' => 'ansible-<2.7.1',
-	'sysutils/borgbackup/1.2' => 'borgbackup-<1.2.5',
 	'sysutils/mcollective' => 'mcollective-<2.5.3',
 	'sysutils/rclone' => 'rclone-<1.53.3',
 	'sysutils/salt' => 'salt-<3002',
@@ -2156,7 +2013,6 @@ my $cve = {
 	'www/tomcat/v8' => 'tomcat-<8.5.55',
 	'www/tomcat/v9' => 'tomcat-<9.0.35',
 	'www/webkitgtk4' => 'webkitgtk4-<2.20.5',
-	'www/yt-dlp' => 'yt-dlp-<2023.11.16',
 	'x11/gnome/gdm' => 'gdm-<3.28.3',
 	'x11/rdesktop' => 'rdesktop-<1.8.4',
 };
